@@ -7,8 +7,6 @@ impl Interval {
     /// | :----------------: | :--------: | :------------------------------------: |
     /// | $\self = ∅$        | $∅$        | $\[c, d\]$                             |
     /// | $\self = \[a, b\]$ | $\[a, b\]$ | $\[\min \set{a, c}, \max \set{b, d}\]$ |
-    ///
-    /// Tightness: tightest
     pub fn convex_hull(self, rhs: Self) -> Self {
         if self.is_empty() {
             return rhs;
@@ -30,8 +28,6 @@ impl Interval {
     /// | :----------------: | :--------: | :------------------------------------: |
     /// | $\self = ∅$        | $∅$        | $∅$                                    |
     /// | $\self = \[a, b\]$ | $∅$        | $\[\max \set{a, c}, \min \set{b, d}\]$ |
-    ///
-    /// Tightness: tightest
     pub fn intersection(self, rhs: Self) -> Self {
         if self.either_empty(rhs) {
             return Self::EMPTY;
@@ -52,8 +48,11 @@ impl Interval {
 }
 
 macro_rules! impl_dec {
-    ($(#[$meta:meta])* $f:ident) => {
-        $(#[$meta])*
+    ($f:ident) => {
+        #[doc = concat!("Applies [`Interval::", stringify!($f), "`] to the interval parts of `self` and `rhs`")]
+        /// and returns the result decorated with [`Decoration::Trv`].
+        ///
+        /// A NaI is returned if `self` or `rhs` is NaI.
         pub fn $f(self, rhs: Self) -> Self {
             if self.is_nai() || rhs.is_nai() {
                 return Self::NAI;
@@ -65,20 +64,8 @@ macro_rules! impl_dec {
 }
 
 impl DecInterval {
-    impl_dec!(
-        /// See [`Interval::convex_hull`].
-        ///
-        /// A NaI is returned if `self` or `rhs` is NaI.
-        /// Otherwise, the result is decorated with [`Decoration::Trv`] regardless of the inputs.
-        convex_hull
-    );
-    impl_dec!(
-        /// See [`Interval::intersection`].
-        ///
-        /// A NaI is returned if `self` or `rhs` is NaI.
-        /// Otherwise, the result is decorated with [`Decoration::Trv`] regardless of the inputs.
-        intersection
-    );
+    impl_dec!(convex_hull);
+    impl_dec!(intersection);
 }
 
 #[cfg(test)]
